@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDMinimizeSplitter.cpp,v 1.1.2.4 2002/12/17 13:54:16 thorsen Exp $
+   $Id: KDMinimizeSplitter.cpp,v 1.1.2.5 2003/07/03 15:03:27 staikos Exp $
 */
 
 /****************************************************************************
@@ -494,7 +494,7 @@ QSplitterLayoutStruct *KDMinimizeSplitter::addWidget( QWidget *w, bool first )
 	s->mode = KeepSize;
 	QString tmp = "qt_splithandle_";
 	tmp += w->name();
-	newHandle = new KDSplitterHandle( orientation(), this, tmp );
+	newHandle = new KDSplitterHandle( orientation(), this, tmp.latin1() );
 	s->wid = newHandle;
 	newHandle->setId(data->list.count());
 	s->isSplitter = TRUE;
