@@ -40,6 +40,7 @@
 #include "kogroupware.h"
 #include "koprefs.h"
 #include "kodialogmanager.h"
+#include "exportwebdialog.h"
 #include <libkcal/calendarimap.h>
 
 extern "C"
@@ -352,6 +353,13 @@ void KOrganizerPart::slotExportVCalendar()
 }
 
 
+void KOrganizerPart::slotExportWebCalendar()
+{
+  ensureWeAreVisible();
+  ExportWebDialog *dlg = new ExportWebDialog( widget->calendar(), widget );
+  dlg->show();
+}
+
 void KOrganizerPart::slotPurgeCompleted()
 {
   ensureWeAreVisible();
@@ -519,6 +527,12 @@ void KOrganizerPart::slotConfigure()
 }
 
 
+void KOrganizerPart::slotToggleFilterView( bool visible )
+{
+  ensureWeAreVisible();
+  widget->showFilter( visible );
+}
+
 void KOrganizerPart::slotNewNote()
 {
   ensureWeAreVisible();
